.. Metagenomic framework documentation master file, created by
   sphinx-quickstart on Wed Dec  4 12:26:50 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

*************************************************
Welcome to Metagenomic framework's documentation!
*************************************************

Contents:

.. toctree::
   :maxdepth: 2

   introduction

   install

   pipeline/index

   scripts/index

   examples/index

   gff

   library

   changes

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

